# ---------------------------------------------------------------------------- #
#
# Project:
# Prominence effect in health care
#
# E Persson & G Tinghg, et al.
#
# This file:
# - Main analyses. All analyses were initially planned and run w/ Stata (analysis.do), this file reproduces the main analyses with R
#
# Created: 2022-09-01
# 
# Emil Persson, R v3.6.1, OS Win 10 x64, Swe
#
# ---------------------------------------------------------------------------- #




# --- Libraries
# -

# --- Local file paths
datapath <- "[FILE PATH HERE]" # Specify file path for folder where you downloaded the data, e.g. something like "C:/Users/Name/Desktop/Prominence/"

# --- Data 
df1 <- read.table(paste0(datapath, "study_1.csv"), 
                 header=T, sep=",", dec=".")
df2 <- read.table(paste0(datapath, "study_2.csv"), 
                  header=T, sep=",", dec=".")

# --- Parameters 
s1_cancer_cost_risky <- 1000000 # cost of risky treatment in cancer scenario, study 1
s1_spinal_cost_risky <- 300000 # cost of risky treatment in spinal disk hern scenario, study 1
s2_cancer_cost_risky <- 100000 # cost of risky treatment in cancer scenario, study 2
s2_spinal_cost_risky <- 30000 # cost of risky treatment in spinal disk hern scenario, study 2










# ---------- Study 1 

# Check stage 1 stated costs
length(df1$pmatch_1) # Cancer scenario -- full sample
length(which(df1$pmatch_1 <= s1_cancer_cost_risky)) # excluded from analysis (as preregistered, see #6)
length(which(df1$pmatch_1 > s1_cancer_cost_risky)) # included (n=660)

length(df1$pmatch_2) # Spinal disk herniation scenario -- full sample
length(which(df1$pmatch_2 <= s1_spinal_cost_risky)) # excluded from analysis (as preregistered, see #6)
length(which(df1$pmatch_2 > s1_spinal_cost_risky)) # included

# Main analysis -- Table 2
table(subset(df1, pmatch_1 > s1_cancer_cost_risky, select=pchoice_1)) # study 1 & scenario 1, number of participants choosing more risky (4) and less risky (5) treatment
prop.test(x=593, n=660, p=0.5) # get proportion and p-value
sqrt(((593/660)*(1-(593/660)))/660) # get standard error of the proportion

table(subset(df1, pmatch_2 > s1_spinal_cost_risky, select=pchoice_2)) # study 1 & scenario 2, number of participants choosing more risky (4) and less risky (5) treatment
prop.test(x=797, n=844, p=0.5) # get proportion and p-value
sqrt(((797/844)*(1-(797/844)))/844) # get standard error of the proportion










# ---------- Study 2

# Sample size & attrition
table(df2$finished_part_1) # n=183 took up the survey and consented to participate, of which n=148 finished the first part of the survey (not in this paper)
length(which(!is.na(df2$pmatch_1))) # n=131 begun the second part (this paper, about prominence); "pmatch_1" was the first question
length(which(!is.na(df2$pchoice_2))) # n=126 finsihed the second part (this paper, about prominence); "pchoice_2" was the final question for this part, before background questions
table(df2$finished_tot) # n=124 finished the full survey, including background questions at the end

# Include subj in sample if they responded to the question we want to analyze (as preregistered, see #7)
# We can select directly on "pchoice_2" since nobody finished only one scenario, either they finished none or both
include_in_sample <- subset(df2, !is.na(pchoice_2))

# Check stage 1 stated costs
length(include_in_sample$pmatch_1) # Cancer scenario -- full sample (all who answered the question)
length(which(include_in_sample$pmatch_1 <= s2_cancer_cost_risky)) # excluded from analysis (as preregistered, see #7)
length(which(include_in_sample$pmatch_1 > s2_cancer_cost_risky)) # included (n=107)

length(include_in_sample$pmatch_2) # Spinal disk herniation scenario -- full sample (all who answered the question)
length(which(include_in_sample$pmatch_2 <= s2_spinal_cost_risky)) # excluded from analysis (as preregistered, see #7)
length(which(include_in_sample$pmatch_2 > s2_spinal_cost_risky)) # included (n=113)

# Main analysis -- Table 3
table(subset(include_in_sample, pmatch_1 > s2_cancer_cost_risky, select=pchoice_1)) # study 2 & scenario 1, number of participants choosing more risky (4) and less risky (5) treatment
prop.test(x=87, n=107, p=0.5) # get proportion and p-value
sqrt(((87/107)*(1-(87/107)))/107) # get standard error of the proportion

table(subset(include_in_sample, pmatch_2 > s2_spinal_cost_risky, select=pchoice_2)) # study 2 & scenario 2, number of participants choosing more risky (4) and less risky (5) treatment
prop.test(x=97, n=113, p=0.5) # get proportion and p-value
sqrt(((97/113)*(1-(97/113)))/113) # get standard error of the proportion











# ---------- Need not run -- basic data checks when drafting the script
str(df1)
any(is.na(df1[c("pmatch_1", "pmatch_2", "pchoice_1", "pchoice_2")])) # study 1 -- ok, no missing in vars we use for main analysis

str(df2)
any(is.na(df2[c("pmatch_1", "pmatch_2", "pchoice_1", "pchoice_2")])) # study 2 -- some are missing, need to handle
any(is.na(df2$pmatch_1[!is.na(df2$pchoice_1)])) # ok, solve this by selecting on nonmissing for choice variable (as preregistered, see #7)
any(is.na(df2$pmatch_2[!is.na(df2$pchoice_2)])) # ok, same as above
identical(subset(df2, !is.na(pchoice_1)), subset(df2, !is.na(pchoice_2))) # nobody finished only one scenario, either none or both; we can thus use same selection for both

